AppleSdkToolchain class final
Apple SDK toolchain implementation.
- Implemented types
Constructors
- AppleSdkToolchain({required Directory sdkDirectory, required String version, ProcessRunner? runner})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runner → ProcessRunner?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sdkDirectory → Directory
-
final
- version → String
-
final
Methods
-
execute(
String command, List< String> args, Directory workingDirectory) → Future<void> -
Execute a command with platform-specific configuration.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited