CmakeConfigureStep class final

CMake configure step.

Configures a CMake project with specified options.

Implemented types

Constructors

CmakeConfigureStep({String id = 'cmake_configure', required String sourceDirectory, String? buildDirectory, Map<String, String> defines = const {}, String? generator, String? toolchainFile, ProcessRunnerInterface? runner})
const
CmakeConfigureStep.fromMap(Map<String, dynamic> map)
Creates a CmakeConfigureStep from a YAML-derived map.
factory

Properties

buildDirectory String?
Path to the build directory (relative to source or absolute).
final
defines Map<String, String>
CMake defines (e.g., -DCMAKE_BUILD_TYPE=Release).
final
generator String?
CMake generator (e.g., Ninja, Unix Makefiles).
final
hashCode int
The hash code for this object.
no setterinherited
id String
Step identifier.
final
runner ProcessRunnerInterface?
Optional process runner.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceDirectory String
Path to the source directory (relative to source root or absolute).
final
toolchainFile String?
Path to a CMake toolchain file.
final

Methods

execute(NativeBuildContext context, ResolvedSource source) Future<NativeStepResult>
Execute this build step.
override
fingerprint(NativeStepContext context) Future<NativeStepFingerprint>
Compute a fingerprint for this step based on its inputs.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialize this step to JSON.
override
toMap() Map<String, dynamic>
Serializes this step to a map suitable for YAML output.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited