fingerprint method
Compute a fingerprint for this step based on its inputs.
Used for build caching to determine if a step needs to be re-executed.
Implementation
@override
Future<NativeStepFingerprint> fingerprint(NativeStepContext context) async {
return NativeStepFingerprint(
id: id,
hash: fingerprintHash(
'$id:${expandRecipeValue(sourcePath, context.buildContext, context.source)}_'
'${expandRecipeValue(destinationPath, context.buildContext, context.source)}',
),
);
}