DownloadArchiveStep class final

Download and extract an archive step.

Downloads an archive from a URL and extracts it.

Implemented types

Constructors

DownloadArchiveStep({required String id, required String url, String? sha256, String? outputDirectory, ProcessRunnerInterface? runner})
const
DownloadArchiveStep.fromMap(Map<String, dynamic> map)
Creates a DownloadArchiveStep from a YAML-derived map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Step identifier.
final
outputDirectory String?
Directory to extract into. Defaults to <work>/<id>.
final
runner ProcessRunnerInterface?
Optional process runner.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sha256 String?
Expected SHA-256 hash of the archive.
final
url String
URL of the archive to download.
final

Methods

execute(NativeBuildContext context, ResolvedSource source) Future<NativeStepResult>
Execute this build step.
override
fingerprint(NativeStepContext context) Future<NativeStepFingerprint>
Compute a fingerprint for this step based on its inputs.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialize this step to JSON.
override
toMap() Map<String, dynamic>
Serializes this step to a map suitable for YAML output.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited