fingerprint method
Compute a fingerprint for this step based on its inputs.
Used for build caching to determine if a step needs to be re-executed.
Implementation
@override
Future<NativeStepFingerprint> fingerprint(NativeStepContext context) async {
final buffer = StringBuffer();
buffer.write(id);
buffer.write(expandRecipeValue(url, context.buildContext, context.source));
if (sha256 != null) {
buffer.write(
expandRecipeValue(sha256!, context.buildContext, context.source),
);
}
return NativeStepFingerprint(
id: id,
hash: fingerprintHash(buffer.toString()),
);
}