source property
Original output from the build.
This can be a File or Directory, allowing things such as .dSYM
directories to be represented.
Implementation
final FileSystemEntity source;
Original output from the build.
This can be a File or Directory, allowing things such as .dSYM
directories to be represented.
final FileSystemEntity source;