NativeArtifactKind enum

Kind of native artifact produced by a build.

Inheritance
Available extensions

Values

dynamicLibrary → const NativeArtifactKind

Dynamic/shared library (.so, .dylib, .dll).

staticLibrary → const NativeArtifactKind

Static library (.a, .lib).

executable → const NativeArtifactKind

Executable binary.

objectFile → const NativeArtifactKind

Object file (.o, .obj).

framework → const NativeArtifactKind

Can be introduced when directory-based Apple bundles are supported.

bundle → const NativeArtifactKind

General directory-style native bundle.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NativeArtifactKind>
A constant List of the values in this enum, in order of their declaration.