NativeArtifactRole enum

Role of an artifact entry within a native artifact bundle.

Inheritance
Available extensions

Values

primary → const NativeArtifactRole

Main file registered with code_assets (the primary library/executable).

runtimeDependency → const NativeArtifactRole

Library that must accompany the primary library at runtime.

importLibrary → const NativeArtifactRole

Windows import library used during linking.

debugSymbols → const NativeArtifactRole

Debug symbols (PDB, dSYM, separate .debug file, etc.).

resource → const NativeArtifactRole

Configuration or data required at runtime.

license → const NativeArtifactRole

License or attribution file.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NativeArtifactRole>
A constant List of the values in this enum, in order of their declaration.