NativeAssetSpec class final

Specification for a native asset to be built or resolved.

Constructors

NativeAssetSpec({required String assetName, required String libraryStem, required LinkMode linkMode})
const
NativeAssetSpec.dynamicLibrary({required String assetName, required String libraryStem})
Creates a dynamic library specification.
factory
NativeAssetSpec.fromJson(Map<String, dynamic> json)
factory
NativeAssetSpec.staticLibrary({required String assetName, required String libraryStem})
Creates a static library specification.
factory

Properties

assetName String
The Dart library path that declares the native code asset.
final
hashCode int
The hash code for this object.
no setterinherited
libraryStem String
The library stem (e.g., 'tdjson' for libtdjson.so).
final
linkMode → LinkMode
The link mode to use.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited