assetName property
The Dart library path that declares the native code asset.
This becomes the code-asset ID under package:<name>/.
Implementation
final String assetName;
The Dart library path that declares the native code asset.
This becomes the code-asset ID under package:<name>/.
final String assetName;