NativeBuildDefinition class final

Definition of how to build a native project for different platforms.

Constructors

NativeBuildDefinition({required List<NativeTargetRecipe> recipes, Map<String, Object?> options = const <String, Object?>{}, Map<String, Object?> variables = const <String, Object?>{}})
const
NativeBuildDefinition.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
options Map<String, Object?>
User-defined values exposed to Liquid recipes as options.*.
final
recipes List<NativeTargetRecipe>
Build recipes with target patterns.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variables Map<String, Object?>
Shared values exposed to Liquid recipes as variables.*.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recipeFor(NativeTarget target) NativeBuildRecipe?
Find the first recipe that matches the given target.
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited