NativeBuildRecipe class abstract interface

Abstract interface for a native build recipe.

A recipe encapsulates the complete build process for a native library, from source acquisition to artifact export.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute(NativeBuildContext context, ResolvedSource source) Future<NativeBuildResult>
Execute the build recipe.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialize this recipe to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited