fingerprint abstract method

Compute a fingerprint for this step based on its inputs.

Used for build caching to determine if a step needs to be re-executed.

Implementation

Future<NativeStepFingerprint> fingerprint(NativeStepContext context);