NativeHookConfiguration class final

Hook configuration for a native build.

Constructors

NativeHookConfiguration({required String packageName, required String assetName, required String libraryStem, required LinkMode linkMode})
const

Properties

assetName String
The Dart library path that declares the native code asset.
final
hashCode int
The hash code for this object.
no setterinherited
libraryStem String
The library stem (e.g., tdjson for libtdjson.so).
final
linkMode → LinkMode
The link mode (dynamic or static).
final
packageName String
The Dart package name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited