NativeProjectBuilder class final

High-level builder that orchestrates the complete native build pipeline.

This handles both prebuilt resolution and source builds through a NativeProject definition.

For packages that use external hook builders (e.g. CBuilder), use NativeProjectBuilder.fromSourceFallback to create an instance from a SourceFallback with a SourceBuilder callback.

Constructors

NativeProjectBuilder({required NativeProject project, SourceFallback? sourceFallback, List<PrebuiltResolver>? resolvers, String localDirectoryName = '.prebuilt'})
const
NativeProjectBuilder.fromSourceFallback({required String assetName, required String libraryStem, required PrebuiltManifest manifest, required LinkMode linkMode, required SourceFallback? sourceFallback, List<PrebuiltResolver>? resolvers, String localDirectoryName = '.prebuilt'})
Creates a NativeProjectBuilder from a SourceFallback with callback.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
localDirectoryName String
Directory name for local prebuilt overrides.
final
project NativeProject
The native project definition.
final
resolvers List<PrebuiltResolver>?
Custom resolver chain override.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceFallback SourceFallback?
Optional source fallback with a SourceBuilder callback.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run({required BuildInput input, required BuildOutputBuilder output, required Logger? logger}) Future<void>
Run the native build pipeline.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited