sourceFallback property
Optional source fallback with a SourceBuilder callback.
When provided and no recipe exists for the target, this is used instead.
Implementation
final SourceFallback? sourceFallback;
Optional source fallback with a SourceBuilder callback.
When provided and no recipe exists for the target, this is used instead.
final SourceFallback? sourceFallback;