source property
The resolved source to build from.
When provided, skips source resolution. When null, sourceFallback is used to resolve the source from the project's source specifications.
Implementation
final ResolvedSource? source;
The resolved source to build from.
When provided, skips source resolution. When null, sourceFallback is used to resolve the source from the project's source specifications.
final ResolvedSource? source;