NativeStepContext class final

Context passed to individual build steps.

Constructors

NativeStepContext({required NativeBuildContext buildContext, required ResolvedSource source, required String stepId})
const

Properties

buildContext NativeBuildContext
The parent build context.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source ResolvedSource
The resolved source being built.
final
stepId String
The identifier of the current step.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited