NativeStepFingerprint class final

Fingerprint for a build step, used for caching.

Constructors

NativeStepFingerprint({required String id, required String hash})
const
NativeStepFingerprint.fromJson(Map<String, dynamic> json)
factory

Properties

hash String
A hash representing the step's inputs and configuration.
final
hashCode int
The hash code for this object.
no setterinherited
id String
The step identifier.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited