Policy for preferring prebuilt artifacts vs building from source.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- forceSourceBuild → const PrebuiltPolicy
- Always build from source, ignore prebuilts.
- preferPrebuilt → const PrebuiltPolicy
- Prefer prebuilt artifacts, fall back to source build.