VcpkgToolchain class final

vcpkg toolchain implementation.

Implemented types

Constructors

VcpkgToolchain({required Directory vcpkgRoot, required String triplet, ProcessRunner? runner})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runner ProcessRunner?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
triplet String
final
vcpkgRoot Directory
final

Methods

execute(String command, List<String> args, Directory workingDirectory) Future<void>
Execute a command with platform-specific configuration.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited