WindowsBuildTarget class final

Platform-specific build configuration for Windows.

Constructors

WindowsBuildTarget({required String msvcArchitecture, required String vcpkgTriplet})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
msvcArchitecture String
The MSVC architecture (e.g., x64, x86).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vcpkgTriplet String
The vcpkg triplet (e.g., x64-windows, x64-windows-static).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited