AtomicFile class final

Utility for writing files atomically using a temporary file + rename.

This prevents partial files from being visible to other processes during writes.

Constructors

AtomicFile()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

writeBytes(File target, List<int> content) Future<void>
Writes content to target atomically.
writeString(File target, String content) Future<void>
Writes content as text to target atomically.