CacheLock class final

A best-effort cross-process file lock for cache population.

Uses an exclusive file lock on a per-cache-key lock file so multiple hook executions do not download/extract the same artifact concurrently.

Constructors

CacheLock(File lockFile)

Properties

hashCode int
The hash code for this object.
no setterinherited
lockFile File
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
withLock<T>(Future<T> action()) Future<T>
Executes action while holding the exclusive lock.

Operators

operator ==(Object other) bool
The equality operator.
inherited