CallbackSourceBuilder class final

A callback-based source builder for one-off build logic.

This is the simplest way to integrate a custom build step without implementing the full SourceBuilder interface.

Implemented types

Constructors

CallbackSourceBuilder({required Future<void> callback({required BuildInput input, required Logger? logger, required BuildOutputBuilder output, required ResolvedSource source})})
const

Properties

callback Future<void> Function({required BuildInput input, required Logger? logger, required BuildOutputBuilder output, required ResolvedSource source})
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build({required ResolvedSource source, required BuildInput input, required BuildOutputBuilder output, required Logger? logger}) Future<void>
Build the native library from source.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited