CommandStepConfig class final

Inheritance
Annotations
  • @JsonSerializable.new(checked: true, disallowUnrecognizedKeys: true, fieldRename: FieldRename.snake)

Constructors

CommandStepConfig({required String id, required List<List<String>> commands, String? workingDirectory, Map<String, String>? environment, List<String> needs = const []})
CommandStepConfig.fromJson(Map<String, dynamic> json)
factory

Properties

commands List<List<String>>
final
environment Map<String, String>?
final
hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier for this step within the recipe.
finalinherited
needs List<String>
Step IDs that must complete before this step runs.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The step type string used for registry dispatch.
no setteroverride
workingDirectory String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBuildStep() NativeBuildStep
Converts this config to its runtime NativeBuildStep equivalent.
override
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited