DefaultArtifactInstaller class final

Default implementation for downloading, verifying, extracting, and validating prebuilt artifacts.

Implemented types

Constructors

DefaultArtifactInstaller({HttpDownloader downloader = const HttpDownloader(), ArchiveReader archiveReader = const ArchiveReader(), NativeBinaryInspector inspector = const NativeBinaryInspector()})

Properties

archiveReader ArchiveReader
final
downloader HttpDownloader
final
hashCode int
The hash code for this object.
no setterinherited
inspector NativeBinaryInspector
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

install({required PrebuiltManifest manifest, required NativeTarget target, required String libraryStem, required ArtifactPayload payload, required Directory cacheDirectory, Logger? logger}) Future<File?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited