GitCheckoutStepConfig class final

Inheritance
Annotations
  • @JsonSerializable.new(checked: true, disallowUnrecognizedKeys: true, fieldRename: FieldRename.snake)

Constructors

GitCheckoutStepConfig({required String id, required String repository, required String revision, String? targetDirectory, bool submodules = false, List<String> needs = const []})
GitCheckoutStepConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier for this step within the recipe.
finalinherited
needs List<String>
Step IDs that must complete before this step runs.
finalinherited
repository String
final
revision String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
submodules bool
final
targetDirectory String?
final
type String
The step type string used for registry dispatch.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBuildStep() NativeBuildStep
Converts this config to its runtime NativeBuildStep equivalent.
override
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited