GitHubReleaseSource class final

Artifacts are hosted as GitHub Release assets.

Inheritance

Constructors

GitHubReleaseSource({required String owner, required String repository, required String tag, Uri? baseUri})
const

Properties

baseUri Uri?
Optional base URI for downloads.
final
baseUrl Uri
The base URL for downloading artifacts from this release.
no setter
hashCode int
The hash code for this object.
no setterinherited
owner String
The GitHub organization or user.
final
repository String
The GitHub repository name.
final
requestHeaders Map<String, String>
Optional request headers needed to download artifacts from this source.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String
The release tag.
final

Methods

artifactUrl(String archiveName) Uri
Constructs the full download URL for an artifact by name.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this release source to JSON.
override
toString() String
A string representation of this object.
override
withTag(String tag) ReleaseSource
Returns a copy of this release source with a different tag.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited