withTag method
Returns a copy of this release source with a different tag.
Implementation
@override
ReleaseSource withTag(String tag) =>
GitLabReleaseSource(projectPath: projectPath, tag: tag, baseUri: baseUri);
Returns a copy of this release source with a different tag.
@override
ReleaseSource withTag(String tag) =>
GitLabReleaseSource(projectPath: projectPath, tag: tag, baseUri: baseUri);