HttpDownloadPolicy class final
Policy for configuring HTTP download behavior.
Constructors
- HttpDownloadPolicy({int maxAttempts = 4, Duration connectionTimeout = const Duration(seconds: 15), Duration responseTimeout = const Duration(minutes: 2), int? maximumBytes})
-
const
Properties
- connectionTimeout → Duration
-
Timeout for establishing a TCP connection.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxAttempts → int
-
Maximum number of retry attempts for transient failures.
final
- maximumBytes → int?
-
Maximum allowed download size in bytes.
final
- responseTimeout → Duration
-
Timeout for receiving the full response body.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited