LocalSourceProvider class final

Resolves LocalSource specifications.

Checks each path in the specification against the package root and returns the first existing directory.

Implemented types

Constructors

LocalSourceProvider()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(SourceResolutionContext context) Future<ResolvedSource?>
Try to resolve the source specification.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited