NativeBinaryInfo class

Information about an inspected binary.

Constructors

NativeBinaryInfo({required String path, required _BinaryFormat format, required int sizeBytes})
const

Properties

format → _BinaryFormat
final
hashCode int
The hash code for this object.
no setterinherited
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizeBytes int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited