validateArchitecture property
Whether to read architecture information from binary headers and compare it against the expected target.
Implementation
final bool validateArchitecture;
Whether to read architecture information from binary headers and compare it against the expected target.
final bool validateArchitecture;