NetworkPolicy enum

Controls network access during source resolution.

Inheritance
Available extensions

Values

allowed → const NetworkPolicy

All network access allowed (default).

prebuiltsOnly → const NetworkPolicy

Only download prebuilt artifacts; no source fetching.

sourceOnly → const NetworkPolicy

Only fetch sources; no prebuilt downloads.

offline → const NetworkPolicy

No network access at all. Only local sources and caches.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NetworkPolicy>
A constant List of the values in this enum, in order of their declaration.