OS class final

An operating system which the Dart VM can run on.

Constructors

OS.fromString(String name)
Creates a OS from the given name.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The name of this operating system.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
The name of this OS.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

current OS
The current OS.
final

Constants

android → const OS
The Android operating system.
fuchsia → const OS
The Fuchsia operating system.
iOS → const OS
The iOS operating system.
linux → const OS
The Linux operating system.
macOS → const OS
The macOS operating system.
osCrossCompilationDefault → const Map<OS, List<OS>>
Typical cross compilation between OSes.
values → const List<OS>
Known values for OS.
windows → const OS
The Microsoft Windows operating system.