PrebuiltArtifact class final

Describes a single prebuilt native artifact within a PrebuiltManifest.

Each artifact has an archive name, integrity hashes for both the archive and the extracted payload, and a description of the payload type.

Constructors

PrebuiltArtifact({required String archiveName, required String archiveSha256, required String payloadSha256, required ArtifactPayload payload})
const
PrebuiltArtifact.fromJson(Map<String, dynamic> json)
factory

Properties

archiveName String
The tarball filename in the GitHub release.
final
archiveSha256 String
SHA-256 hash of the downloaded archive file.
final
hashCode int
The hash code for this object.
no setterinherited
payload ArtifactPayload
Describes the type and naming of the expected payload within the archive.
final
payloadSha256 String
SHA-256 hash of the selected native library after extraction.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited