payloadSha256 property
SHA-256 hash of the selected native library after extraction.
Verified after extraction and selection to ensure the correct binary was unpacked.
Implementation
final String payloadSha256;
SHA-256 hash of the selected native library after extraction.
Verified after extraction and selection to ensure the correct binary was unpacked.
final String payloadSha256;