PrebuiltResolutionContext class final

Context passed to resolvers during the resolution chain.

Constructors

PrebuiltResolutionContext({required BuildInput input, required PrebuiltManifest manifest, required NativeTarget target, required String libraryStem, required ArtifactPayload payload, required Directory localSearchRoot, Logger? logger})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
input → BuildInput
final
libraryStem String
final
localSearchRoot Directory
final
logger → Logger?
Logger used to emit resolution progress messages.
final
manifest PrebuiltManifest
final
payload ArtifactPayload
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target NativeTarget
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited