ReleaseSource class sealed

Describes where prebuilt artifacts are published.

Implementers

Constructors

ReleaseSource.fromJson(Map<String, dynamic> json)
Deserializes a release source from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
requestHeaders Map<String, String>
Optional request headers needed to download artifacts from this source.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String
The release tag.
no setter

Methods

artifactUrl(String archiveName) Uri
Constructs the full download URL for an artifact by name.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this release source to JSON.
toString() String
A string representation of this object.
inherited
withTag(String tag) ReleaseSource
Returns a copy of this release source with a different tag.

Operators

operator ==(Object other) bool
The equality operator.
inherited