ResolutionAttempt class final

A single resolution attempt.

Constructors

ResolutionAttempt({required PrebuiltSource source, required bool success, String? path, String? error})
const

Properties

error String?
final
hashCode int
The hash code for this object.
no setterinherited
path String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source PrebuiltSource
final
success bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited