ResolvedFile class final

A file that has been resolved and is ready to use.

Constructors

ResolvedFile({required String path, required String hash})
const

Properties

hash String
SHA-256 hash of the file.
final
hashCode int
The hash code for this object.
no setterinherited
path String
Path to the native library file.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited