ResolvedPrebuiltNotFound class final
No prebuilt was found; the caller should fall back to building from source.
- Inheritance
-
- Object
- ResolvedPrebuilt
- ResolvedPrebuiltNotFound
Constructors
-
ResolvedPrebuiltNotFound({required String reason, required List<
ResolutionAttempt> attempts}) -
const
Properties
-
attempts
→ List<
ResolutionAttempt> -
All resolution attempts made.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- reason → String
-
A human-readable summary of why resolution failed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited