RunCommand class final

Runs a custom shell command in the source directory.

Inheritance

Constructors

RunCommand({required String executable, List<String> arguments = const [], Map<String, String>? environment})
const

Properties

arguments List<String>
final
environment Map<String, String>?
final
executable String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply({required Directory directory, required Logger? logger}) Future<void>
Apply this preparation step to the source directory.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited