SharedCacheResolver class final
Resolves prebuilts from the shared hook cache (outputDirectoryShared) by downloading from the release source.
- Implemented types
Constructors
-
const
Properties
- downloader → HttpDownloader
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inspector → NativeBinaryInspector
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
PrebuiltResolutionContext context) → Future< ResolvedPrebuilt?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited