SourceProvider class abstract interface

Resolves a SourceSpecification into a ResolvedSource directory.

Providers are tried in order by SourceFallbackResolver. The first to return a non-null result wins.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(SourceResolutionContext context) Future<ResolvedSource?>
Try to resolve the source specification.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited