UserDefinePrebuiltResolver class final

Resolves prebuilts from hooks.user_defines configuration.

In pubspec.yaml:

hooks:
  user_defines:
    my_package:
      prebuilt_path: /absolute/path/to/library.so
Implemented types

Constructors

UserDefinePrebuiltResolver({String key = 'prebuilt_path'})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(PrebuiltResolutionContext context) Future<ResolvedPrebuilt?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited