readManifestSnapshot function
Decodes a generated manifest file without searching arbitrary text.
Implementation
ManifestSnapshot readManifestSnapshot(File file) {
return parseManifestSnapshot(file.readAsStringSync(), path: file.path);
}
Decodes a generated manifest file without searching arbitrary text.
ManifestSnapshot readManifestSnapshot(File file) {
return parseManifestSnapshot(file.readAsStringSync(), path: file.path);
}