AndroidBuildTarget class final
Platform-specific build configuration for Android.
Constructors
- AndroidBuildTarget({required String abi, required int requestedApi, required int effectiveApi, required Directory ndk})
-
const
Properties
- abi → String
-
The Android ABI (e.g.,
arm64-v8a,x86_64).final - effectiveApi → int
-
The effective API level after resolution.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ndk → Directory
-
The Android NDK directory.
final
- requestedApi → int
-
The API level requested by the build.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited