AppleBuildTarget class final
Platform-specific build configuration for Apple platforms.
Constructors
- AppleBuildTarget({required IOSSdk sdk, required String deploymentTarget, required Architecture architecture, required bool isSimulator})
-
const
Properties
- architecture → Architecture
-
The target CPU architecture.
final
- deploymentTarget → String
-
The minimum deployment target (e.g.,
17.0).final - hashCode → int
-
The hash code for this object.
no setterinherited
- isSimulator → bool
-
Whether this is a simulator build.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sdk → IOSSdk
-
The Apple SDK (e.g.,
iphoneos,iphonesimulator,macosx).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited