BuiltNativeArtifact class final
A built native artifact ready for packaging.
Represents a deployable native artifact bundle with a primary output and optional companion files (runtime dependencies, debug symbols, etc.).
Constructors
-
BuiltNativeArtifact({required String id, required NativeTarget target, required NativeArtifactKind kind, required NativeArtifactEntry primary, List<
NativeArtifactEntry> companions = const [], Map<String, Object?> metadata = const {}}) -
const
-
BuiltNativeArtifact.dynamicLibrary({required String id, required NativeTarget target, required NativeArtifactEntry primary, List<
NativeArtifactEntry> companions = const [], Map<String, Object?> metadata = const {}}) -
Creates a dynamic library artifact with optional companions.
factory
-
BuiltNativeArtifact.executable({required String id, required NativeTarget target, required NativeArtifactEntry primary, List<
NativeArtifactEntry> companions = const [], Map<String, Object?> metadata = const {}}) -
Creates an executable artifact with optional companions.
factory
-
BuiltNativeArtifact.fromJson(Map<
String, dynamic> json) -
factory
-
BuiltNativeArtifact.staticLibrary({required String id, required NativeTarget target, required NativeArtifactEntry primary, List<
NativeArtifactEntry> companions = const [], Map<String, Object?> metadata = const {}}) -
Creates a static library artifact with optional companions.
factory
Properties
-
companions
→ List<
NativeArtifactEntry> -
Files/directories that belong to the same deployable bundle.
final
-
entries
→ Iterable<
NativeArtifactEntry> -
All entries in this artifact bundle (primary + companions).
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Logical identity within the project.
final
- kind → NativeArtifactKind
-
What the primary native output represents.
final
-
metadata
→ Map<
String, Object?> -
Source revision, toolchain versions, build fingerprint, etc.
final
- primary → NativeArtifactEntry
-
The library or executable registered as the principal artifact.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- target → NativeTarget
-
Platform and architecture this artifact targets.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited