CommandStep class final
Generic command execution step.
Runs one or more commands with arguments, optionally in a working directory.
- Implemented types
Constructors
-
CommandStep({required String id, required List<
List< commands, String? workingDirectory, Map<String> >String, String> ? environment, ProcessRunnerInterface? runner}) -
const
-
CommandStep.fromMap(Map<
String, dynamic> map) -
Creates a CommandStep from a YAML-derived map.
factory
Properties
-
commands
→ List<
List< String> > -
Commands to execute in order. Each entry is
executable, ...args.final -
environment
→ Map<
String, String> ? -
Environment variables to pass to the process.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Step identifier.
final
- runner → ProcessRunnerInterface?
-
Optional process runner.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- workingDirectory → String?
-
Working directory for all commands.
final
Methods
-
execute(
NativeBuildContext context, ResolvedSource source) → Future< NativeStepResult> -
Execute this build step.
override
-
fingerprint(
NativeStepContext context) → Future< NativeStepFingerprint> -
Compute a fingerprint for this step based on its inputs.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serialize this step to JSON.
override
-
toMap(
) → Map< String, dynamic> - Serializes this step to a map suitable for YAML output.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited