CopyStep class final
Copy files or directories.
- Implemented types
Constructors
Properties
- destinationPath → String
-
Destination path.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
A unique identifier for this step.
final
- recursive → bool
-
Whether to copy directories recursively.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourcePath → String
-
Source file or directory path.
final
Methods
-
execute(
NativeBuildContext context, ResolvedSource source) → Future< NativeStepResult> -
Execute this build step.
override
-
fingerprint(
NativeStepContext context) → Future< NativeStepFingerprint> -
Compute a fingerprint for this step based on its inputs.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serialize this step to JSON.
override
-
toMap(
) → Map< String, dynamic> - Serializes this step to a map suitable for YAML output.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited