GitApplyPatchStep class final
Apply a git patch.
- Implemented types
Constructors
- GitApplyPatchStep({String id = 'git_apply_patch', required String patchPath, String? targetDirectory, ProcessRunnerInterface? runner})
-
const
-
GitApplyPatchStep.fromMap(Map<
String, dynamic> map) -
Creates a GitApplyPatchStep from a YAML-derived map.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
A unique identifier for this step.
final
- patchPath → String
-
Path to the patch file (relative to source or absolute).
final
- runner → ProcessRunnerInterface?
-
Optional process runner.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetDirectory → String?
-
Target directory to apply patch (relative to work dir or absolute).
final
Methods
-
execute(
NativeBuildContext context, ResolvedSource source) → Future< NativeStepResult> -
Execute this build step.
override
-
fingerprint(
NativeStepContext context) → Future< NativeStepFingerprint> -
Compute a fingerprint for this step based on its inputs.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serialize this step to JSON.
override
-
toMap(
) → Map< String, dynamic> - Serializes this step to a map suitable for YAML output.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited