GitCheckoutStep class final
Git checkout step.
Clones a git repository at a specific revision.
- Implemented types
Constructors
- GitCheckoutStep({required String id, required String repository, required String revision, String? targetDirectory, bool submodules = false, ProcessRunnerInterface? runner})
-
const
-
GitCheckoutStep.fromMap(Map<
String, dynamic> map) -
Creates a GitCheckoutStep from a YAML-derived map.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Step identifier.
final
- repository → String
-
Repository URL (e.g., https://github.com/org/repo.git).
final
- revision → String
-
Revision to checkout (commit SHA, tag, or branch).
final
- runner → ProcessRunnerInterface?
-
Optional process runner.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- submodules → bool
-
Whether to initialize and update submodules.
final
- targetDirectory → String?
-
Target directory (relative to work directory or absolute).
final
Methods
-
execute(
NativeBuildContext context, ResolvedSource source) → Future< NativeStepResult> -
Execute this build step.
override
-
fingerprint(
NativeStepContext context) → Future< NativeStepFingerprint> -
Compute a fingerprint for this step based on its inputs.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serialize this step to JSON.
override
-
toMap(
) → Map< String, dynamic> - Serializes this step to a map suitable for YAML output.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited