NativeArtifactCompanion class final
A companion entry in an artifact declaration.
Constructors
- NativeArtifactCompanion({required String path, required NativeArtifactRole role, bool optional = false})
-
const
-
NativeArtifactCompanion.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- optional → bool
-
Whether this companion is optional (e.g., debug symbols).
final
- path → String
-
Relative path to the companion file in the build output.
final
- role → NativeArtifactRole
-
Role of this companion within the artifact bundle.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited