NativeArtifactDeclaration class final
Declarative description of an artifact to export.
Used by ExportArtifactStep to know what artifact to produce. Paths are resolved relative to the build output directory.
Constructors
-
NativeArtifactDeclaration({required String id, required NativeArtifactKind kind, required String primaryPath, List<
NativeArtifactCompanion> companions = const []}) -
const
-
NativeArtifactDeclaration.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
companions
→ List<
NativeArtifactCompanion> -
Companion entries (runtime deps, import libs, debug symbols, etc.).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Logical identity for the artifact (e.g., 'tdjson').
final
- kind → NativeArtifactKind
-
What kind of native output this is.
final
- primaryPath → String
-
Relative path to the primary artifact in the build output.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited