NativeArtifactEntry class final
An entry within a native artifact bundle.
Each entry represents a file or directory that is part of the deployable artifact bundle, with a specific role and destination path.
Constructors
- NativeArtifactEntry({required FileSystemEntity source, required String path, required NativeArtifactRole role, bool optional = false})
-
const
- NativeArtifactEntry.debugSymbols({required FileSystemEntity source, required String path, bool optional = true})
-
Creates a debug symbols entry from a file or directory.
factory
-
NativeArtifactEntry.fromJson(Map<
String, dynamic> json) -
factory
- NativeArtifactEntry.importLibrary({required File source, required String path})
-
Creates an import library entry from a file.
factory
- NativeArtifactEntry.license({required File source, required String path})
-
Creates a license entry from a file.
factory
- NativeArtifactEntry.primary({required File source, required String path})
-
Creates a primary entry from a file.
factory
- NativeArtifactEntry.resource({required FileSystemEntity source, required String path})
-
Creates a resource entry from a file or directory.
factory
- NativeArtifactEntry.runtimeDependency({required File source, required String path})
-
Creates a runtime dependency entry from a file.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- optional → bool
-
Whether this entry is optional (e.g., debug symbols that may not exist).
final
- path → String
-
Relative path inside the staged artifact bundle.
final
- role → NativeArtifactRole
-
Role of this entry within the artifact bundle.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → FileSystemEntity
-
Original output from the build.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited