NativeBuildContext class final
Configuration for a native build.
Contains all the information needed to compile a native library for a specific target platform.
Constructors
-
NativeBuildContext({required NativeTarget target, required NativeHookConfiguration hook, required NativeBuildDirectories directories, required ToolchainRegistry toolchains, required Map<
String, String> environment, Map<String, Object?> options = const <String, Object?>{}, Map<String, Object?> variables = const <String, Object?>{}, Logger? logger}) -
const
Properties
- directories → NativeBuildDirectories
-
The build directories (source, output, cache, etc.).
final
-
environment
→ Map<
String, String> -
Environment variables to pass to build tools.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hook → NativeHookConfiguration
-
The hook configuration.
final
- logger → Logger?
-
Optional logger for build output.
final
-
options
→ Map<
String, Object?> -
User-defined recipe values from
build.options.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- target → NativeTarget
-
The target platform to build for.
final
- toolchains → ToolchainRegistry
-
The available toolchains for this build.
final
-
variables
→ Map<
String, Object?> -
Shared recipe values from the manifest's
variablessection.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited