NativeBuildDirectories class final
Directories used during a native build.
Constructors
- NativeBuildDirectories({required Directory source, required Directory output, required Directory cache, required Directory work})
-
const
Properties
- cache → Directory
-
The cache directory for intermediate build results.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- output → Directory
-
The output directory for built artifacts.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → Directory
-
The source directory.
final
- work → Directory
-
The working directory for the build process.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited