NativeBuildResult class final
Result of a native build operation.
Contains the built artifacts and optional metadata about the build.
Constructors
-
NativeBuildResult({required List<
BuiltNativeArtifact> artifacts, Map<String, Object?> metadata = const {}}) -
const
-
NativeBuildResult.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
artifacts
→ List<
BuiltNativeArtifact> -
The native artifacts produced by the build.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
→ Map<
String, Object?> -
Optional metadata about the build (e.g., build duration, toolchain versions).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited