A single step in a native build recipe.
Constructors
-
NativeBuildStep.fromJson(Map<
String, dynamic> json) -
Deserialize a step from JSON.
factory
Properties
Methods
-
execute(
NativeBuildContext context, ResolvedSource source) → Future< NativeStepResult> - Execute this build step.
-
fingerprint(
NativeStepContext context) → Future< NativeStepFingerprint> - Compute a fingerprint for this step based on its inputs.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serialize this step to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited