NativeStepResult class final
Result of executing a single build step.
Contains any artifacts produced by the step. Most steps return an empty result. Only steps that produce exportable artifacts (like ExportArtifactStep) return non-empty results.
Constructors
-
NativeStepResult({List<
BuiltNativeArtifact> artifacts = const []}) -
const
-
NativeStepResult.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
artifacts
→ List<
BuiltNativeArtifact> -
Artifacts produced by this step.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited