NativeTargetRecipe class final
A recipe associated with a target pattern.
Constructors
- NativeTargetRecipe({required NativeTargetPattern pattern, required NativeBuildRecipe recipe})
-
const
-
NativeTargetRecipe.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- pattern → NativeTargetPattern
-
The target pattern this recipe handles.
final
- recipe → NativeBuildRecipe
-
The build recipe to execute.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited