ProcessResult class final
Result of a process execution.
Constructors
- ProcessResult({required int exitCode, required String stdout, required String stderr})
-
const
Properties
- exitCode → int
-
The exit code of the process.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSuccess → bool
-
Whether the process completed successfully.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stderr → String
-
The standard error of the process.
final
- stdout → String
-
The standard output of the process.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited