Abstract interface for running external processes.
This interface allows testing build steps with fake process runners.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
runStreaming(
String executable, List< String> arguments, {Directory? workingDirectory, Map<String, String> ? environment, bool requireSuccess = true}) → Future<ProcessResult> - Run a command and stream output in real-time.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited