StripStep class final
Strip debug symbols from a binary.
- Implemented types
Constructors
- StripStep({required String id, required String inputPath, required String outputPath, bool stripAll = false, ProcessRunnerInterface? runner})
-
const
-
StripStep.fromMap(Map<
String, dynamic> map) -
Creates a StripStep from a YAML-derived map.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
A unique identifier for this step.
final
- inputPath → String
-
Source file to strip (relative to work dir or absolute).
final
- outputPath → String
-
Output file path (relative to work dir or absolute).
final
- runner → ProcessRunnerInterface?
-
Optional process runner.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stripAll → bool
-
Whether to strip all symbols (not just debug).
final
Methods
-
execute(
NativeBuildContext context, ResolvedSource source) → Future< NativeStepResult> -
Execute this build step.
override
-
fingerprint(
NativeStepContext context) → Future< NativeStepFingerprint> -
Compute a fingerprint for this step based on its inputs.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serialize this step to JSON.
override
-
toMap(
) → Map< String, dynamic> - Serializes this step to a map suitable for YAML output.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited