ToolchainRegistry class final
Registry of available platform toolchains.
Constructors
- ToolchainRegistry({AndroidNdkToolchain? androidNdk, AppleSdkToolchain? appleSdk, MsvcToolchain? msvc, VcpkgToolchain? vcpkg})
-
const
Properties
- androidNdk → AndroidNdkToolchain?
-
The Android NDK toolchain.
final
- appleSdk → AppleSdkToolchain?
-
The Apple SDK toolchain.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- msvc → MsvcToolchain?
-
The MSVC toolchain.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- vcpkg → VcpkgToolchain?
-
The vcpkg toolchain.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited