ApplyPatches class final
Applies one or more patch files to the source directory.
Patches are applied in order using the patch command.
- Inheritance
-
- Object
- SourcePreparation
- ApplyPatches
Constructors
-
ApplyPatches({required List<
String> paths, bool reverse = false}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
paths
→ List<
String> -
Relative paths to patch files, resolved against the package root.
final
- reverse → bool
-
If true, apply patches in reverse (useful for un-applying).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apply(
{required Directory directory, required Logger? logger}) → Future< void> -
Apply this preparation step to the source
directory.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited