ArchiveEntry class final
Describes an entry within a tar/gz archive.
Constructors
Properties
- basename → String
-
The basename (final component) of the entry path.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFile → bool
-
Whether the entry is a regular file.
final
- isHardLink → bool
-
Whether the entry is a hard link.
final
- isSafePath → bool
-
Whether the entry path is safe (no absolute paths, no traversal).
no setter
- isSymlink → bool
-
Whether the entry is a symbolic link.
final
- name → String
-
The full path of the entry within the archive.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
The uncompressed size in bytes.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited