ArchiveSelectionContext class final
Context for selecting an entry from an archive.
Constructors
- ArchiveSelectionContext({required String canonicalName, bool acceptVersionedNames = true})
-
const
Properties
- acceptVersionedNames → bool
-
Whether versioned library names are acceptable.
final
- canonicalName → String
-
The expected canonical filename of the library.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited