DownloadArchiveStepConfig class final
- Inheritance
-
- Object
- BuildStepConfig
- DownloadArchiveStepConfig
- Annotations
-
- @JsonSerializable.new(checked: true, disallowUnrecognizedKeys: true, fieldRename: FieldRename.snake)
Constructors
-
DownloadArchiveStepConfig({required String id, required String url, String? sha256, String? outputDirectory, List<
String> needs = const []}) -
DownloadArchiveStepConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier for this step within the recipe.
finalinherited
-
needs
→ List<
String> -
Step IDs that must complete before this step runs.
finalinherited
- outputDirectory → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sha256 → String?
-
final
- type → String
-
The step type string used for registry dispatch.
no setteroverride
- url → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBuildStep(
) → NativeBuildStep -
Converts this config to its runtime NativeBuildStep equivalent.
override
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited