DynamicLibraryPayload class final
A shared/dynamic library (.so, .dylib, .dll).
- Inheritance
-
- Object
- ArtifactPayload
- DynamicLibraryPayload
Constructors
- DynamicLibraryPayload({required String libraryStem, bool acceptVersionedNames = true})
-
const
Properties
- acceptVersionedNames → bool
-
Whether versioned library names are acceptable.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- libraryStem → String
-
The library stem without platform prefix or extension.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited