GitLabReleaseSource class final
Artifacts are hosted as GitLab release assets.
- Inheritance
-
- Object
- ReleaseSource
- GitLabReleaseSource
Constructors
- GitLabReleaseSource({required String projectPath, required String tag, Uri? baseUri})
-
const
Properties
- baseUri → Uri?
-
Optional base URI for downloads.
final
- baseUrl → Uri
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- projectPath → String
-
The GitLab project path or numeric project id.
final
-
requestHeaders
→ Map<
String, String> -
Optional request headers needed to download artifacts from this source.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String
-
The release tag.
final
Methods
-
artifactUrl(
String archiveName) → Uri -
Constructs the full download URL for an artifact by name.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this release source to JSON.
override
-
toString(
) → String -
A string representation of this object.
override
-
withTag(
String tag) → ReleaseSource -
Returns a copy of this release source with a different tag.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited