GitSourceProvider class final
Resolves GitSource specifications.
Clones the repository at the specified revision with --depth=1
and caches the result.
- Implemented types
Constructors
- GitSourceProvider({String gitExecutable = 'git', Logger? logger})
-
const
Properties
- gitExecutable → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- logger → Logger?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
SourceResolutionContext context) → Future< ResolvedSource?> -
Try to resolve the source specification.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited