HookBuilderSourceBuilder class final
Adapter that wraps a hooks Builder as a SourceBuilder.
This enables existing hooks builders like CBuilder or RustBuilder
to be used with PrebuiltCodeAssetBuilder's source fallback system.
- Implemented types
Constructors
- HookBuilderSourceBuilder({required Builder builderFactory(BuildInput input, ResolvedSource source)})
-
const
- HookBuilderSourceBuilder.factory(Builder builderFactory(BuildInput input, ResolvedSource source))
-
Creates a HookBuilderSourceBuilder from a factory function.
factory
- HookBuilderSourceBuilder.static(Builder builder)
-
Creates a HookBuilderSourceBuilder from a static builder instance.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
{required ResolvedSource source, required BuildInput input, required BuildOutputBuilder output, required Logger? logger}) → Future< void> -
Build the native library from
source.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited