LocalPrebuiltResolver class final
Resolves prebuilts from the local .prebuilt/ directory.
Searches up from the build output directory and from the package root.
- Implemented types
Constructors
- LocalPrebuiltResolver({String directoryName = '.prebuilt'})
-
const
Properties
- directoryName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
PrebuiltResolutionContext context) → Future< ResolvedPrebuilt?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited