ManifestArtifactHashes class final
Hashes recorded for one platform in a generated or lock manifest.
Constructors
- ManifestArtifactHashes({String? archiveName, required String archiveSha256, required String payloadSha256})
-
const
Properties
- archiveName → String?
-
The archive filename, when present in a generated Dart manifest.
final
- archiveSha256 → String
-
The SHA-256 hash of the release archive.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- payloadSha256 → String
-
The SHA-256 hash of the extracted native payload.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited