ManifestSnapshot class final
The integrity fields decoded from a generated Dart or lock manifest.
Constructors
-
ManifestSnapshot({required String releaseTag, required Map<
String, ManifestArtifactHashes> artifacts}) -
const
Properties
-
artifacts
→ Map<
String, ManifestArtifactHashes> -
Integrity records keyed by canonical platform label.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- releaseTag → String
-
The exact release tag recorded by the manifest.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited