NativeTarget class final
Canonical representation of a native build target.
Uses the official code_assets platform types directly.
Constructors
- NativeTarget({required OS os, required Architecture architecture, IOSSdk? iOSSdk})
-
const
Properties
- architecture → Architecture
-
The target CPU architecture.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- iOSSdk → IOSSdk?
-
The iOS SDK, when targeting iOS.
final
- label → String
-
A canonical platform label like
linux-x64,macos-arm64, orios-sim-arm64.no setter - os → OS
-
The target operating system.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override