NoOpSourceBuilder class final
A no-op source builder used as a placeholder in source fallback configurations where the actual build is handled by a separate recipe system (e.g. NativeBuildRecipe).
This is used by BuildCommand and other CLI tools that delegate
to NativeProjectExecutor without providing an explicit
SourceFallback.
- Implemented types
Constructors
- NoOpSourceBuilder()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
{required ResolvedSource source, required BuildInput input, required BuildOutputBuilder output, required Logger? logger}) → Future< void> -
Build the native library from
source.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited