Abstract interface for resolving prebuilt artifacts.
Implementations are tried in order by PrebuiltCodeAssetBuilder. The first to return a non-null result wins.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
PrebuiltResolutionContext context) → Future< ResolvedPrebuilt?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited