ResolvedPrebuiltFound class final
A prebuilt was found and installed successfully.
- Inheritance
-
- Object
- ResolvedPrebuilt
- ResolvedPrebuiltFound
Constructors
- ResolvedPrebuiltFound({required ResolvedFile file, required PrebuiltSource source})
-
const
Properties
- file → ResolvedFile
-
The installed native library file.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → PrebuiltSource
-
Which resolver found the prebuilt.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited