ResolvedSource class final
A resolved source directory ready for preparation and building.
Constructors
- ResolvedSource({required Directory directory, required SourceOrigin origin, String? revision})
-
const
Properties
- directory → Directory
-
Directory containing the source code.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- origin → SourceOrigin
-
How the source was acquired.
final
- revision → String?
-
Commit SHA or archive hash, if applicable.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited