Compiles source code into a native library.
Implement this interface for each build system (Rust, CMake, Zig, etc.). The builder receives a resolved source directory and must produce a native library compatible with the hooks output.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
{required ResolvedSource source, required BuildInput input, required BuildOutputBuilder output, required Logger? logger}) → Future< void> -
Build the native library from
source. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited