SourceFallbackResolver class final
Resolves and builds from source as a fallback when prebuilts fail.
This is the source-side equivalent of SharedCacheResolver. It runs after the prebuilt resolution chain has been exhausted.
Constructors
-
SourceFallbackResolver({List<
SourceProvider> providers = const [LocalSourceProvider(), ArchiveSourceProvider(), GitSourceProvider()]}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
providers
→ List<
SourceProvider> -
Source providers in priority order.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
{required SourceFallback fallback, required Directory packageRoot, required Directory sourceCacheRoot, required BuildInput input, required BuildOutputBuilder output, required Logger? logger}) → Future< SourceBuildResult?> - Resolve, prepare, and build from source.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited