SourcePreparation class sealed
A preparation step applied to source code before building.
Preparation runs after source acquisition but before compilation. The most common use case is applying patches.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apply(
{required Directory directory, required Logger? logger}) → Future< void> -
Apply this preparation step to the source
directory. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited