SourceResolutionContext class final
Context passed to source providers during resolution.
Constructors
- SourceResolutionContext({required SourceSpecification specification, required Directory packageRoot, required Directory sourceCacheRoot})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- packageRoot → Directory
-
Root directory of the Dart package.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceCacheRoot → Directory
-
Root directory for caching downloaded/cloned sources.
final
- specification → SourceSpecification
-
The source specification to resolve.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sourceCacheDirectory(
{required String key}) → Directory - Compute a cache subdirectory for a given repository and revision.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited